import axios from '@/api/axios.ts'
import { BasePaginationData, BaseRespData } from '@/types/api'
import {
  warehouseSearchForm,
  InterWarehousePage,
  InterWarehouseDetail,
  InterWarehouseTree,
  InterskuList,
  InterWarehouseList,
  ILocation,
  InRecordEditForm
} from '@/types/api/warehouse'
export interface factoryWarehouseInfo {
  pageSize: number
  currentPage: number
  total?: number
}
export interface UpdateDefaulted {
  id?: number
  defaulted: number
}
export interface warehouseInfo {
  id?: number
  name: string
  code: string
  sort: string
  defaulted: number
  factoryId?: number
  factoryCode?: string
  remarks: string
}
interface WarehouseWarningData {
  id: number
  factoryId: number
  warehouseId: number
  warehouseName: string
  warehouseLocationId: number
  locationName: string
  warehouseSku: string
  skuName: string
  unit: string
  occupyInventory: number
  freezeInventory: number
  inventory: number
  upperLimit: number
  floorLimit: number
  productNumber: string
  itemSort: number
  dataVersion: number
  status: number
  createTime: string
  updateTime: string
}
export function getFactoryWarehouseInfo(data: factoryWarehouseInfo) {
  return axios.post<never, BasePaginationData<warehouseInfo>>(
    'factoryWarehouseInfo/list_page',
    data,
  )
}
export function createWarehouseApi(data: warehouseInfo) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseInfo/add',
    data,
  )
}

export function createWarehouseInventoryApi(data: WarehouseWarningData) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseInventory/add',
    data,
  )
}
export function updateWarehouseApi(data: warehouseInfo | UpdateDefaulted) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseInfo/update',
    data,
  )
}
export function updateWarehouseInventoryApi(data: WarehouseWarningData) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseInventory/update',
    data,
  )
}
export function deleteWarehouseApi(ids: string) {
  return axios.get<never, BaseRespData<never>>('/factoryWarehouseInfo/delete', {
    params: { ids },
  })
}
export function deleteWarehouseInventory(ids: string) {
  return axios.get<never, BaseRespData<never>>(
    '/factoryWarehouseInventory/delete',
    {
      params: { ids },
    },
  )
}
// 入库单

export function warehouseInRecordListPage(
  data: warehouseSearchForm,
  currentPage: number,
  pageSize: number,
) {
  return axios.post<never, BasePaginationData<InterWarehousePage>>(
    '/factory/warehouseInRecord/list_page',
    {
      ...data,
      currentPage,
      pageSize,
    },
  )
}
export function addInRecordApi(form: InRecordEditForm) {
  return axios.post<never, BaseRespData<never>>('factory/warehouseInRecord/add', {
    ...form,
  })
}
export function updateInRecordApi(form: InRecordEditForm) {
  return axios.post<never, BaseRespData<never>>('factory/warehouseInRecord/update', {
    ...form,
  })
}
export function getWarehouseInRecordDetail(id: number) {
  return axios.get<never, BaseRespData<never>>(
    'factory/warehouseInRecord/get',
    {
      params: {
        id,
      },
    },
  )
}
export function getBySku(warehouseId: number, sku: string | null) {
  return axios.get<never, BaseRespData<InterskuList[]>>(
    'customProductItem/getBySku',
    {
      params: {
        warehouseId,
        sku,
      },
    },
  )
}
export function getByWareHouseIdAndCode(wareHouseId: number, code: string | null) {
  return axios.get<never, BaseRespData<ILocation[]>>(
    'factoryWarehouseLocation/getByWareHouseIdAndCode',
    {
      params: {
        wareHouseId,
        code,
      },
    },
  )
}
export function getWarehouseStatusTree() {
  return axios.get<never, BaseRespData<InterWarehouseTree[]>>(
    'factory/warehouseInRecord/status_tree',
  )
}
export function getWarehouseListApi() {
  return axios.get<never, BaseRespData<InterWarehouseList[]>>(
    'factoryWarehouseInfo/getAll',
  )
}
